@@ -77,10 +77,12 @@ insert_NAs <- function(x, original) {
 #' @export
 augment_columns <- function(x, data, newdata, type, type.predict = type,
                             type.residuals = type, se.fit = TRUE, ...) {
+    notNAs <- function(o) if (is.null(o) || all(is.na(o))) { NULL } else {o}
     residuals0 <- failwith(NULL, residuals, TRUE)
     influence0 <- failwith(NULL, influence, TRUE)
     cooks.distance0 <- failwith(NULL, cooks.distance, TRUE)
     rstandard0 <- failwith(NULL, rstandard, TRUE)
+    predict0 <- failwith(NULL, predict, TRUE)
     
     # call predict with arguments
     args <- list(x)
@@ -92,7 +94,11 @@ augment_columns <- function(x, data, newdata, type, type.predict = type,
     }
     args$se.fit <- se.fit
     args <- c(args, list(...))
-    pred <- do.call(predict, args)
+    pred <- do.call(predict0, args)
+    if (is.null(pred)) {
+        # try "fitted" instead- some objects don't have "predict" method
+        pred <- do.call(fitted, args)
+    }
 
     if (is.list(pred)) {
         ret <- data.frame(.fitted = pred$fit)
@@ -120,8 +126,10 @@ augment_columns <- function(x, data, newdata, type, type.predict = type,
             ret$.sigma <- infl$sigma
         }
         
-        ret$.cooksd <- cooks.distance0(x)
-        ret$.std.resid <- rstandard0(x)
+        # if cooksd and rstandard can be computed and aren't all NA
+        # (as they are in rlm), do so
+        ret$.cooksd <- notNAs(cooks.distance0(x))
+        ret$.std.resid <- notNAs(rstandard0(x))
         
         original <- data
         
